'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactMotion = require('react-motion');

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ScoreBar = function ScoreBar(_ref) {
    var bottombar = _ref.bottombar,
        _ref$score = _ref.score,
        score = _ref$score === undefined ? 0 : _ref$score,
        _ref$responses = _ref.responses,
        responses = _ref$responses === undefined ? 0 : _ref$responses;


    var percentage = responses > 0 ? calculateScore(score, responses) : 0;
    var barColor = renderBarColor(percentage);

    return _react2.default.createElement(
        'div',
        { className: 'score-bar' },
        _react2.default.createElement(
            'div',
            { style: styles.container },
            'Score',
            _react2.default.createElement(
                'div',
                { style: styles.bar },
                _react2.default.createElement(
                    _reactMotion.Motion,
                    { style: { x: (0, _reactMotion.spring)(percentage) } },
                    function (_ref2) {
                        var x = _ref2.x;
                        return _react2.default.createElement(
                            'div',
                            { style: { width: x + '%', background: barColor }
                            },
                            _react2.default.createElement(
                                'p',
                                { style: styles.percentage },
                                percentage,
                                '%'
                            )
                        );
                    }
                )
            )
        ),
        bottombar && _react2.default.createElement('div', { className: 'bottom-bar' })
    );
};

ScoreBar.propTypes = {
    /** Number of correct answers */
    score: _propTypes2.default.number.isRequired,

    /** Total number of answers  */
    responses: _propTypes2.default.number.isRequired,

    /** Renders white bar at the bottom of component */
    bottombar: _propTypes2.default.bool
};

var styles = {
    container: {
        display: 'flex',
        alignItems: 'center'
    },
    bar: {
        width: 200,
        height: 25,
        backgroundColor: '#000',
        display: 'flex',
        alignItems: 'stretch',
        borderRadius: 2,
        marginLeft: 10,
        padding: 1
    },
    percentage: {
        margin: 0,
        paddingLeft: 6,
        paddingTop: 0,
        paddingBottom: 0,
        fontSize: 15,
        color: '#f2f2f2',
        lineHeight: '25px'
    }
};

function calculateScore(score, responses) {
    return Math.round(score / responses * 100);
}

function renderBarColor(percentage) {
    if (percentage < 50) {
        return "red";
    } else if (percentage < 80) {
        return "#ef9c62";
    }
    return "#44cc54";
}

exports.default = ScoreBar;